import { useConfig } from '@abearxiong/use-config';
import { Ollama, Message, ChatRequest } from 'ollama';

const config = useConfig<{ ollama: Ollama['config'] & { model: string } }>();

const { host } = config.ollama;

export const ollama = new Ollama({ host });

export type ChatMessage = {
  content: string;
} & Message;

type ChatOpts = {
  model?: string;
  messages?: ChatMessage[];
  options?: ChatRequest['options'];
} & ChatRequest;
export const chat = (messages: ChatMessage[], chatOpts?: ChatOpts) => {
  const { options, stream, ...rest } = chatOpts || {};
  return ollama.chat({
    messages,
    model: config.model,
    options: {
      temperature: 0,
      ...chatOpts?.options,
    },
    ...rest,
  });
};
