import { PromptNeo } from '@/models/prompt.ts';
import { app } from '@/app.ts';
import { v4 } from 'uuid';
app
  .route('prompt', 'list')
  .define(async (ctx) => {
    const prompts = await PromptNeo.all();
    const json = await prompts.toJson();
    console.log('json', json);
    ctx.body = json;
  })
  .addTo(app);

app
  .route('prompt', 'update')
  .define(async (ctx) => {
    const { id, title, description, prompt, inputVariables, localVariables } = ctx.query;
    const promptNode = await PromptNeo.first('id', id);

    if (!promptNode) {
      const promptData = {
        id: v4(),
        title,
        description,
        prompt,
        inputVariables: JSON.stringify(inputVariables),
        localVariables: JSON.stringify(localVariables),
      };
      const _prompt = await PromptNeo.create(promptData);
      ctx.body = await _prompt.toJson();
      return;
    }

    await promptNode.update({ title, description, prompt, inputVariables, localVariables });
    ctx.body = await promptNode.toJson();
  })
  .addTo(app);

app
  .route('prompt', 'delete')
  .define(async (ctx) => {
    const { id, title } = ctx.query;
    const promptNode = await PromptNeo.first('id', id);
    if (!promptNode) {
      ctx.body = 'prompt not found';
      return;
    }
    await promptNode.delete();
    ctx.body = 'delete success';
  })
  .addTo(app);
app
  .route('prompt', 'deleteAll')
  .define(async (ctx) => {
    const prompts = await PromptNeo.all();
    for (const prompt of prompts) {
      await prompt.delete();
    }
    ctx.body = 'delete all success';
  })
  .addTo(app);
app
  .route('prompt', 'createDemo')
  .define(async (ctx) => {
    const promptData = {
      id: v4(),
      title: 'test',
      description: '这是测试保存prompt的数据',
      prompt: '这是测试保存prompt的数据',
      inputVariables: JSON.stringify([{ key: 'test', value: 'test' }]),
      localVariables: JSON.stringify([{ key: 'test', value: 'test' }]),
    };
    const prompt = await PromptNeo.create(promptData);
    ctx.body = await prompt.toJson();
  })
  .addTo(app);
